@@ -28,23 +28,33 @@ def tag(version):
     """ Defines tag to deploy """
 
     if "pydiploy_version" in env:
-        fabric.api.abort(fabric.colors.red(
-            "tag should be set before calling goal (ex: fab tag:master test deploy)"))
+        fabric.api.abort(
+            fabric.colors.red(
+                "tag should be set before calling goal (ex: fab tag:master test deploy)"
+            )
+        )
     if check_tag_exist(version):
         env.tag = version
     else:
-        fabric.api.abort(fabric.colors.red(
-            "tag/branch provided is not in the repository please fix this first"))
+        fabric.api.abort(
+            fabric.colors.red(
+                "tag/branch provided is not in the repository please fix this first"
+            )
+        )
 
 
 def init_params(application_type='default'):
     """ Sets required params and its description """
 
     try:
-        required_params, optional_params = PARAMS[application_type]['required_params'], PARAMS[application_type]['optional_params']
+        required_params, optional_params = (
+            PARAMS[application_type]['required_params'],
+            PARAMS[application_type]['optional_params'],
+        )
     except KeyError:
-        fabric.api.abort(fabric.colors.red(
-            "application_type '%s' doesn't exists" % application_type))
+        fabric.api.abort(
+            fabric.colors.red("application_type '%s' doesn't exists" % application_type)
+        )
     return required_params, optional_params
 
 
@@ -57,14 +67,22 @@ def build_env():
     if "req_pydiploy_version" in env:
         if not check_req_pydiploy_version():
             if not fabric.contrib.console.confirm(
-                    "\nYour fabfile require pydiploy %s and pydiploy %s is installed ! \
+                "\nYour fabfile require pydiploy %s and pydiploy %s is installed ! \
                     \nBe sure that your fabfile complies last pydiploy evolutions. \
                     \nContinue at your own risks ! \
-                    \n\nDo you want to continue?" %
-                    (fabric.colors.red(env.req_pydiploy_version),
-                        fabric.colors.red(__version__)), default=False):
+                    \n\nDo you want to continue?"
+                % (
+                    fabric.colors.red(env.req_pydiploy_version),
+                    fabric.colors.red(__version__),
+                ),
+                default=False,
+            ):
                 fabric.api.abort("Aborting at user request.")
 
+    # remote home cannot be empty or / path
+    if not 'remote_home' in env or not env.remote_home or env.remote_home == "/":
+        fabric.api.abort("The remote home cannot be empty or /.")
+
     # defines destination path for fetched file(s)
     if "dest_path" not in env:
         env.dest_path = env.local_tmp_dir
@@ -75,20 +93,21 @@ def build_env():
         env.remote_project_dir = os.path.join(env.remote_home, env.application_name)
 
     if "tag" in env:
-        env.local_tmp_root_app = os.path.join(env.local_tmp_dir,
-                                              '%(application_name)s-%(tag)s' % env)
-        env.local_tmp_root_app_package = os.path.join(env.local_tmp_root_app,
-                                                      env.root_package_name)
+        env.local_tmp_root_app = os.path.join(
+            env.local_tmp_dir, '%(application_name)s-%(tag)s' % env
+        )
+        env.local_tmp_root_app_package = os.path.join(
+            env.local_tmp_root_app, env.root_package_name
+        )
 
     env.remote_current_path = os.path.join(env.remote_project_dir, 'current')
     env.remote_releases_path = os.path.join(env.remote_project_dir, 'releases')
     env.remote_shared_path = os.path.join(env.remote_project_dir, 'shared')
-    env.remote_base_package_dir = os.path.join(env.remote_current_path,
-                                               env.root_package_name)
-    env.remote_settings_dir = os.path.join(
-        env.remote_base_package_dir, 'settings')
-    env.remote_settings_file = os.path.join(env.remote_settings_dir,
-                                            '%s.py' % env.goal)
+    env.remote_base_package_dir = os.path.join(
+        env.remote_current_path, env.root_package_name
+    )
+    env.remote_settings_dir = os.path.join(env.remote_base_package_dir, 'settings')
+    env.remote_settings_file = os.path.join(env.remote_settings_dir, '%s.py' % env.goal)
     env.lib_path = os.path.dirname(__file__)
 
     if "previous_settings_file" not in env:
@@ -117,7 +136,11 @@ def build_env():
         application_type = 'default'
 
     if not test_config(verbose=verbose_value, application_type=application_type):
-        if not fabric.contrib.console.confirm("Configuration test %s! Do you want to continue?" % fabric.colors.red('failed'), default=False):
+        if not fabric.contrib.console.confirm(
+            "Configuration test %s! Do you want to continue?"
+            % fabric.colors.red('failed'),
+            default=False,
+        ):
             fabric.api.abort("Aborting at user request.")
 
 
@@ -139,15 +162,21 @@ def test_config(verbose=True, application_type='default'):
     max_opt_desc_length = max(map(len, opt_params.values()))
     current_role = _get_current_role()
 
-    fabric.api.puts("\n\nConfiguration checking for role : %s, host : %s" % (
-        fabric.colors.green(current_role), fabric.colors.green(env.host)))
+    fabric.api.puts(
+        "\n\nConfiguration checking for role : %s, host : %s"
+        % (fabric.colors.green(current_role), fabric.colors.green(env.host))
+    )
     for param, desc in sorted(req_params.items()):
         if param not in env:
-            err.append("%s -> %s : missing" %
-                       (param.ljust(max_req_param_length), desc.ljust(max_req_desc_length)))
+            err.append(
+                "%s -> %s : missing"
+                % (param.ljust(max_req_param_length), desc.ljust(max_req_desc_length))
+            )
         elif not bool(env[param]):
-            err.append("%s -> %s : not set" %
-                       (param.ljust(max_req_param_length), desc.ljust(max_req_desc_length)))
+            err.append(
+                "%s -> %s : not set"
+                % (param.ljust(max_req_param_length), desc.ljust(max_req_desc_length))
+            )
         elif verbose:
             req_parameters.append((param, env[param], desc))
 
@@ -161,30 +190,38 @@ def test_config(verbose=True, application_type='default'):
         err_nb = len(err)
         if err_nb == len(req_params):
             fabric.api.puts(
-                'You need to configure correctly the fabfile please RTFM first !')
+                'You need to configure correctly the fabfile please RTFM first !'
+            )
         else:
-            fabric.api.puts('Config test failed (%s error%s) for role %s:' %
-                            (err_nb, 's' if err_nb > 1 else '', current_role))
-            fabric.api.puts('%s\n\n* %s\n' % ('-' * 30, '\n* '.join(err)))
             fabric.api.puts(
-                'Please fix them or continue with possible errors.')
+                'Config test failed (%s error%s) for role %s:'
+                % (err_nb, 's' if err_nb > 1 else '', current_role)
+            )
+            fabric.api.puts('%s\n\n* %s\n' % ('-' * 30, '\n* '.join(err)))
+            fabric.api.puts('Please fix them or continue with possible errors.')
         return False
     elif verbose:
         fabric.api.puts('\n\nRequired parameters list : \n\n')
         for param, value, description in req_parameters:
-            fabric.api.puts('* %s %s' %
-                            (param.ljust(max_req_param_length), fabric.colors.green(value)))
+            fabric.api.puts(
+                '* %s %s'
+                % (param.ljust(max_req_param_length), fabric.colors.green(value))
+            )
         fabric.api.puts('\n\nOptional parameters list : \n\n')
         if len(opt_parameters):
             for param, value, description in opt_parameters:
-                value = fabric.colors.red("Warning initialized but not set") if not bool(
-                    str(value)) ^ bool(value == None) else fabric.colors.green(value)
-                fabric.api.puts('* %s %s' %
-                                (param.ljust(max_opt_param_length), value))
+                value = (
+                    fabric.colors.red("Warning initialized but not set")
+                    if not bool(str(value)) ^ bool(value == None)
+                    else fabric.colors.green(value)
+                )
+                fabric.api.puts('* %s %s' % (param.ljust(max_opt_param_length), value))
         else:
             fabric.api.puts("No optional parameter found")
-    fabric.api.puts('\n\nRole : %s -> configuration %s!\n\n' %
-                    (fabric.colors.green(current_role), fabric.colors.green("OK")))
+    fabric.api.puts(
+        '\n\nRole : %s -> configuration %s!\n\n'
+        % (fabric.colors.green(current_role), fabric.colors.green("OK"))
+    )
     return True
 
 
@@ -206,8 +243,9 @@ def check_req_pydiploy_version():
     if "req_pydiploy_version" in env:
         major_version_installed = __version_info__[0:2]
         major_version_required = tuple(
-            [int(num) for num in env.req_pydiploy_version.split('.')])
-        if (major_version_installed != major_version_required[0:2]):
+            [int(num) for num in env.req_pydiploy_version.split('.')]
+        )
+        if major_version_installed != major_version_required[0:2]:
             return False
         return True
 
@@ -240,23 +278,32 @@ def generate_fabfile_bottle():
 def process_releases():
     """ Populates env vars for releases (current, old...) """
     if fabtools.files.is_dir(env.remote_releases_path):
-        env.releases = sorted(fabric.api.run('ls -x %(releases_path)s' %
-                                             {'releases_path': env.remote_releases_path}).split())
+        env.releases = sorted(
+            fabric.api.run(
+                'ls -x %(releases_path)s' % {'releases_path': env.remote_releases_path}
+            ).split()
+        )
         if len(env.releases) >= 1:
             env.current_revision = env.releases[-1]
-            env.current_release = "%(releases_path)s/%(current_revision)s" % \
-                                  {'releases_path': env.remote_releases_path,
-                                   'current_revision': env.current_revision}
+            env.current_release = "%(releases_path)s/%(current_revision)s" % {
+                'releases_path': env.remote_releases_path,
+                'current_revision': env.current_revision,
+            }
             # warning previous settings file before deployement !!!!!
             env.previous_release_base_package_dir = os.path.join(
-                env.current_release, env.root_package_name)
+                env.current_release, env.root_package_name
+            )
             env.previous_release_settings_dir = os.path.join(
-                env.previous_release_base_package_dir, 'settings')
+                env.previous_release_base_package_dir, 'settings'
+            )
             env.previous_settings_file = os.path.join(
-                env.previous_release_settings_dir, '%s.py' % env.goal)
+                env.previous_release_settings_dir, '%s.py' % env.goal
+            )
+            fabric.api.puts("settings :", env.previous_settings_file)
 
         if len(env.releases) > 1:
             env.previous_revision = env.releases[-2]
-            env.previous_release = "%(releases_path)s/%(previous_revision)s" % \
-                                   {'releases_path': env.remote_releases_path,
-                                    'previous_revision': env.previous_revision}
+            env.previous_release = "%(releases_path)s/%(previous_revision)s" % {
+                'releases_path': env.remote_releases_path,
+                'previous_revision': env.previous_revision,
+            }
