@@ -5,9 +5,10 @@
 import os
 import random
 import re
+
 import fabric
 import fabtools
-from fabric.api import env
+from fabric.api import env, hide, warn_only
 from pydiploy.decorators import do_verbose
 
 
@@ -16,8 +17,7 @@ def generate_secret_key():
     """ Generates the django's secret key. """
 
     letters = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*(-_=+)'
-    random_letters = map(lambda i: random.SystemRandom().choice(letters),
-                         range(50))
+    random_letters = map(lambda i: random.SystemRandom().choice(letters), range(50))
 
     env.secret_key = ''.join(random_letters)
 
@@ -27,9 +27,11 @@ def extract_settings():
     """ Extracts settings from django settings files. """
 
     # get the remote file
-    fabric.api.get(env.previous_settings_file, local_path=env.local_tmp_dir)
-    settings_file = os.path.join(env.local_tmp_dir, '%s.py' % env.goal)
+    # with warn_only(), hide():
+    with hide('everything'):
+        fabric.api.get(env.previous_settings_file, local_path=env.local_tmp_dir)
 
+    settings_file = os.path.join(env.local_tmp_dir, '%s.py' % env.goal)
     # open and read the data from the downloaded file
     with open(settings_file, 'r') as settings_fh:
         settings_data = settings_fh.readlines()
@@ -58,13 +60,10 @@ def extract_settings():
 def app_settings(**kwargs):
     """ Manages django settings file """
 
-    settings_present = fabtools.files.is_file(path=env.previous_settings_file,
-                                              use_sudo=True)
+    settings_present = fabtools.files.is_file(path=env.previous_settings_file, use_sudo=True)
 
     # if values are set within the --set option on command line
-    kwargs.update({
-        key: value for key, value in env.items() if key in env.map_settings
-    })
+    kwargs.update({key: value for key, value in env.items() if key in env.map_settings})
 
     if settings_present:
         fabric.api.execute(extract_settings)
@@ -80,44 +79,48 @@ def app_settings(**kwargs):
     fabric.api.require(*env.map_settings.keys())
     settings_dir = os.path.join(env.local_tmp_root_app_package, 'settings')
 
-    fabtools.files.upload_template('%s.py' % env.goal,
-                                   env.remote_settings_file,
-                                   template_dir=settings_dir,
-                                   context=env,
-                                   use_sudo=True,
-                                   user=env.remote_owner,
-                                   mode='644',
-                                   chown=True,
-                                   use_jinja=True)
+    fabtools.files.upload_template(
+        '%s.py' % env.goal,
+        env.remote_settings_file,
+        template_dir=settings_dir,
+        context=env,
+        use_sudo=True,
+        user=env.remote_owner,
+        mode='644',
+        chown=True,
+        use_jinja=True,
+    )
 
 
 @do_verbose
 def deploy_manage_file():
     """ uploads manage.py template on remote """
 
-    fabtools.files.upload_template('manage.py',
-                                   os.path.join(
-                                       env.remote_current_release, 'manage.py'),
-                                   template_dir=env.local_tmp_root_app,
-                                   context=env,
-                                   use_sudo=True,
-                                   user=env.remote_owner,
-                                   chown=True,
-                                   mode='744',
-                                   use_jinja=True)
+    fabtools.files.upload_template(
+        'manage.py',
+        os.path.join(env.remote_current_release, 'manage.py'),
+        template_dir=env.local_tmp_root_app,
+        context=env,
+        use_sudo=True,
+        user=env.remote_owner,
+        chown=True,
+        mode='744',
+        use_jinja=True,
+    )
 
 
 @do_verbose
 def deploy_wsgi_file():
     """ Uploads wsgi.py template on remote """
 
-    fabtools.files.upload_template('wsgi.py',
-                                   os.path.join(
-                                       env.remote_base_package_dir, 'wsgi.py'),
-                                   template_dir=env.local_tmp_root_app_package,
-                                   context=env,
-                                   use_sudo=True,
-                                   user=env.remote_owner,
-                                   chown=True,
-                                   mode='644',
-                                   use_jinja=True)
+    fabtools.files.upload_template(
+        'wsgi.py',
+        os.path.join(env.remote_base_package_dir, 'wsgi.py'),
+        template_dir=env.local_tmp_root_app_package,
+        context=env,
+        use_sudo=True,
+        user=env.remote_owner,
+        chown=True,
+        mode='644',
+        use_jinja=True,
+    )
