@@ -6,9 +6,8 @@ from time import time
 
 import fabric
 import fabtools
-from fabric.api import env, hide, warn_only
-
 import pydiploy
+from fabric.api import env, hide, warn_only
 from pydiploy.decorators import do_verbose
 
 
@@ -92,7 +91,8 @@ def deploy_code():
         env.tag = tag_requested
 
     env.local_tmp_root_app = os.path.join(
-        env.local_tmp_dir, '%(application_name)s-%(tag)s' % env
+        env.local_tmp_dir,
+        '%s-%s' % (env.application_name, env.tag.lower()),
     )
     env.local_tmp_root_app_package = os.path.join(
         env.local_tmp_root_app, env.root_package_name
@@ -120,7 +120,7 @@ def deploy_code():
         # use tarball to get commit id
         with warn_only():
             env.commit_id = fabric.api.local(
-                'zcat %s | git get-tar-commit-id' % os.path.basename(tarball),
+                'gunzip -c %s | git get-tar-commit-id' % os.path.basename(tarball),
                 capture=True,
             )
         fabric.api.local('tar xvf %s' % os.path.basename(tarball))
@@ -133,13 +133,16 @@ def deploy_code():
                 {
                     'app_host': env.host_string,
                     'repo_url': env.remote_repo_url,
-                    'python_version': env.remote_python_version,
                     'local_user': env.local_user,
-                    'socket_port': env.socket_port,
                     'tag': env.tag,
                     'commit_id': env.commit_id,
                 }
             ]
+            if 'python_version' in env:
+                data['info'][0].update({'python_version': env.remote_python_version})
+
+            if 'socket_port' in env:
+                data['info'][0].update({'socket_port': env.socket_port})
 
             json.dump(data, f)
 
